CosmoSpectra
-------------
CosmoSpectra package is meant for Fourier analysis of cosmological simulations.
For full documentation, look [here](https://cosmospectra.readthedocs.io/en/latest/).

PREREQUISITES
-------------
1. [Numpy](http://www.numpy.org/)
2. [Scipy](https://scipy.org/install.html)
3. [Numba](https://numba.pydata.org/)
4. [Astropy](https://www.astropy.org/)

INSTALLATION
------------
To install the package in the standard location, run the following in the root directory::

    python setup.py install

In order to install it in a separate directory::

    python setup.py install --home=directory

One can also install it using pip by running the following command::

    pip install git+https://github.com/sambit-giri/cosmospectra.git
